@@ -136,6 +136,44 @@ get_pool_config_from_json(char *json_data, int data_len)
 			goto ERROR_EXIT;
 		strncpy(config->backend_desc->backend_info[i].backend_hostname, ptr, sizeof(config->backend_desc->backend_info[i].backend_hostname) - 1);
 	}
+    /* per node health check parameters */
+    value = json_get_value_for_key(root, "health_check_params");
+    /* We don't get seperate health check params from older version
+     * so be kind if the JSON does not contain one
+     */
+    if (value != NULL && value->type == json_array)
+    {
+        int health_check_params_count = value->u.array.length;
+        if (health_check_params_count != config->backend_desc->num_backends)
+        {
+            ereport(LOG,
+                    (errmsg("unexpected number of health check parameters received"),
+                     errdetail("expected:%d got %d",config->backend_desc->num_backends,health_check_params_count)));
+        }
+        config->health_check_params = palloc0(sizeof(HealthCheckParams) * config->backend_desc->num_backends);
+        
+        
+        if (health_check_params_count > config->backend_desc->num_backends)
+            health_check_params_count = config->backend_desc->num_backends;
+        
+        for (i = 0; i < health_check_params_count; i++)
+        {
+            json_value *arr_value = value->u.array.values[i];
+            
+            if (json_get_int_value_for_key(arr_value, "health_check_timeout", &config->health_check_params[i].health_check_timeout))
+                config->health_check_params[i].health_check_timeout = 0;
+            if (json_get_int_value_for_key(arr_value, "health_check_period", &config->health_check_params[i].health_check_period))
+                config->health_check_params[i].health_check_period = 0;
+            if (json_get_int_value_for_key(arr_value, "health_check_max_retries", &config->health_check_params[i].health_check_max_retries))
+                config->health_check_params[i].health_check_max_retries = 0;
+            if (json_get_int_value_for_key(arr_value, "health_check_retry_delay", &config->health_check_params[i].health_check_retry_delay))
+                config->health_check_params[i].health_check_retry_delay = 0;
+            if (json_get_int_value_for_key(arr_value, "connect_timeout", &config->health_check_params[i].connect_timeout))
+                config->health_check_params[i].connect_timeout = 0;
+        }
+    }
+    else
+        config->health_check_params = NULL;
 
 	/* wd_remote_nodes array */
 	value = json_get_value_for_key(root, "wd_remote_nodes");
@@ -214,6 +252,23 @@ get_pool_config_json(void)
 	jw_put_bool(jNode, "failover_require_consensus", pool_config->failover_require_consensus);
 	jw_put_bool(jNode, "allow_multiple_failover_requests_from_node", pool_config->allow_multiple_failover_requests_from_node);
 
+	/* Array of health_check params
+	 * We transport num_backend at max
+	 */
+	jw_start_array(jNode, "health_check_params");
+	for (i = 0; i < pool_config->backend_desc->num_backends; i++)
+	{
+		jw_start_object(jNode, "HealthCheckParams");
+
+		jw_put_int(jNode, "health_check_timeout", pool_config->health_check_params[i].health_check_timeout);
+		jw_put_int(jNode, "health_check_period", pool_config->health_check_params[i].health_check_period);
+		jw_put_int(jNode, "health_check_max_retries", pool_config->health_check_params[i].health_check_max_retries);
+		jw_put_int(jNode, "health_check_retry_delay", pool_config->health_check_params[i].health_check_retry_delay);
+		jw_put_int(jNode, "connect_timeout", pool_config->health_check_params[i].connect_timeout);
+		jw_end_element(jNode);
+	}
+	jw_end_element(jNode);		/* backend_desc array End */
+
 	/* Array of backends */
 	jw_start_array(jNode, "backend_desc");
 	for (i = 0; i < pool_config->backend_desc->num_backends; i++)
@@ -243,7 +298,7 @@ get_pool_config_json(void)
 	return json_str;
 }
 
-/* The function returs the simple JSON string that contains
+/* The function returns the simple JSON string that contains
  * only one KEY,VALUE along with the authkey key value if provided
  */
 char *
